pub enum KeyType {
AttrNames,
Text,
None,
}Expand description
Type of the keys allowed for Overlay Object
Variants
AttrNames
Keys names needs to correspond to the attribute names from Capture Base
Text
Keys are any arbitrary string
None
Key type for attribtues which are simple pairs, and do not have keys