pub enum Rule {
Show 62 variants
EOI,
ws,
iws,
arg_ws,
line_continuation,
comment,
comment_line,
empty_line,
meta_attr_key,
meta_attr_value,
meta_key_pair,
meta_comment,
meta_comment_line,
string,
single_quoted_string,
single_quoted_inner,
double_quoted_string,
inner,
escape,
unicode,
SCRIPTS,
char,
file,
overlay_block,
overlay_header,
overlay_name,
overlay_body,
overlay_entry,
overlay_version,
unique_keys_command,
unique_key,
unique_keys,
overlay_object,
overlay_object_header,
overlay_object_body,
overlay_array,
overlay_array_header,
overlay_array_body,
overlay_attributes,
keys_with_values,
key_pair,
attr_value_type,
attr_name,
version,
key_type,
ATTR_NAMES_TYPE,
TEXT_TYPE,
REF_TYPE,
ANY_TYPE,
LANG_TYPE,
ATTR_ARRAY,
ARRAY_KEY_TYPE,
array_content,
array_items,
trailing_ellipsis,
key_item,
value_type,
object_type,
array_type,
overlay_array_type_body,
complex_value_type,
complex_type,
}Variants
EOI
End-of-input
ws
insignificant whitespace, not repeated
iws
2 spaces or tab allowed for indented line
arg_ws
line_continuation
a line continuation, allowing an instruction to continue onto a new line
comment
comment_line
empty_line
meta_attr_key
meta_attr_value
meta_key_pair
meta_comment
meta_comment_line
string
single_quoted_string
single_quoted_inner
double_quoted_string
inner
escape
unicode
SCRIPTS
char
file
overlay_block
overlay_header
overlay_name
Overlay name including namespace
overlay_body
overlay_entry
overlay_version
The version of the overlay
unique_keys_command
unique_key
List of attributes which are uniquely identifing overlay
unique_keys
overlay_object
overlay_object_header
overlay_object_body
overlay_array
overlay_array_header
overlay_array_body
overlay_attributes
keys_with_values
key_pair
attr_value_type
attr_name
version
key_type
Type of the keys allowed for given object,
- “attr-names” - attribute from capture base,
- “Text” - any string,
- “array” - array of strings either fixed or with ellipsis allowing additional strings
ATTR_NAMES_TYPE
TEXT_TYPE
REF_TYPE
ANY_TYPE
Don’t validate value of the key, just allow any type
LANG_TYPE
ISO 639-1 (+country code) or 639-3 language code
ATTR_ARRAY
ARRAY_KEY_TYPE
array_content
array_items
trailing_ellipsis
key_item
value_type
object_type
array_type
overlay_array_type_body
complex_value_type
complex_type
Implementations